# BRiskTyper
Genome pre-processing pipeline for BRisk

## Overview

BRiskTyper is a genomic pre-processing pipeline for BRisk.

Post issues at https://github.com/lmc297/BRiskTyper/issues.

------------------------------------------------------------------------

## Installation

XXX Stay tuned! XXX To add XXX

------------------------------------------------------------------------

## Citation

### If you found the BRiskTyper tool, its source code, and/or any of its associated databases useful, please cite:

> XXX

------------------------------------------------------------------------


## Quick Start

### Command Structure

```
brisktyper -i [fasta] -o [output directory] [options...]
```

For help, type `brisktyper -h` or `brisktyper --help`

For your current version, type `brisktyper --version`

------------------------------------------------------------------------

Disclaimer: BRiskTyper is pretty neat! However, no tool is perfect, and BRiskTyper cannot definitively prove whether an isolate is pathogenic or not. As always, interpret your results with caution. We are not responsible for taxonomic misclassifications, misclassifications of an isolate's pathogenic potential or industrial utility, and/or misinterpretations (biological, statistical, or otherwise) of BRiskTyper results.
